@@ -80,7 +80,11 @@
 #define EINA_MAGIC_MATRIXSPARSE_CELL_ITERATOR 0x98761248
 #define EINA_MAGIC_MATRIXSPARSE_CELL_ACCESSOR 0x98761249
 
+#define EINA_MAGIC_STRBUF 0x98761250
 
+#define EINA_MAGIC_QUADTREE 0x98761251
+#define EINA_MAGIC_QUADTREE_ROOT 0x98761252
+#define EINA_MAGIC_QUADTREE_ITEM 0x98761253
 
 /* undef the following, we want out version */
 #undef FREE
