@@ -28,17 +28,13 @@
 # include <glib.h>
 #endif
 
-#ifdef EINA_BENCH_HAVE_EVAS
-# include <Evas.h>
-#endif
-
-#ifdef EINA_BENCH_HAVE_ECORE
-# include <Ecore_Data.h>
-#endif
+#include "Evas_Data.h"
+#include "Ecore_Data.h"
 
 #include "eina_stringshare.h"
 #include "eina_bench.h"
 #include "eina_convert.h"
+#include "eina_main.h"
 
 static void
 eina_bench_stringshare_job(int request)
@@ -104,8 +100,6 @@ eina_bench_stringchunk_job(int request)
 }
 #endif
 
-#ifdef EINA_BENCH_HAVE_EVAS
-#if 0
 static void
 eina_bench_evas_job(int request)
 {
@@ -113,9 +107,6 @@ eina_bench_evas_job(int request)
    unsigned int j;
    int i;
 
-   evas_init();
-/*    evas_stringshare_init(); */
-
    for (i = 0; i < request; ++i)
      {
 	char build[64] = "string_";
@@ -134,14 +125,8 @@ eina_bench_evas_job(int request)
 	  eina_convert_xtoa(rand() % request, build + 7);
 	  tmp = evas_stringshare_add(build);
        }
-
-/*    evas_stringshare_shutdown(); */
-   evas_shutdown();
 }
-#endif
-#endif
 
-#ifdef EINA_BENCH_HAVE_ECORE
 static void
 eina_bench_ecore_job(int request)
 {
@@ -172,7 +157,6 @@ eina_bench_ecore_job(int request)
 
    ecore_string_shutdown();
 }
-#endif
 
 void eina_bench_stringshare(Eina_Benchmark *bench)
 {
@@ -180,12 +164,6 @@ void eina_bench_stringshare(Eina_Benchmark *bench)
 #ifdef EINA_BENCH_HAVE_GLIB
    eina_benchmark_register(bench, "stringchunk (glib)", EINA_BENCHMARK(eina_bench_stringchunk_job), 100, 20100, 500);
 #endif
-#ifdef EINA_BENCH_HAVE_EVAS
-#if 0
    eina_benchmark_register(bench, "stringshare (evas)", EINA_BENCHMARK(eina_bench_evas_job), 100, 20100, 500);
-#endif
-#endif
-#ifdef EINA_BENCH_HAVE_ECORE
    eina_benchmark_register(bench, "stringshare (ecore)", EINA_BENCHMARK(eina_bench_ecore_job), 100, 20100, 500);
-#endif
 }
